from skyline_solver import skyline_solver

# Skyline vector of a symmetric matrix
# 1-based indexing must be used
m=[1,1,2,3,1]

# The matrix initialization
sk=skyline_solver(m)

# The matrix is initialized with zero values by default. 
# However, the initial values can be set using the set method:
sk.set(0.0)


print("The rank is:", sk.rank)
print("The number of non-zero values is:", sk.nnz)

# Adding values according to 1-based indexing scheme.
sk.add_value(1,1,2.0)
sk.add_value(1,2,-2.0)
sk.add_value(1,5,-1.0)

sk.add_value(2,2,3.0)
sk.add_value(2,3,-2.0)

sk.add_value(3,3,5.0)
sk.add_value(3,4,-3.0)

sk.add_value(4,4,10.0)
sk.add_value(4,5,4.0)

sk.add_value(5,5,10.0)

print("The matrix in the dense format is:")
print(sk.to_dense())

# The factorization is done inplace.
sk.decompose()

print("The factorized matrix in the dense format is:")
print(sk.to_dense())

# Constants or load vectors 
f=[0,1,0,0,0]

# Providing in place solution
f = sk.solve(f)

print("The solution is:")
print(f) 
print("The solution from Finite Element Procedures By K. J. Bathe (Example 8.5) is:")
print([636, 619, 292, 74, 34])



from setuptools import find_packages
import setuptools

from numpy.distutils.core import setup, Extension

ext1 = Extension(name='skyline',
                 sources=['skyline_solver/skyline/skyline.f90'],
                 f2py_options=['--quiet'],
                 #extra_f90_compile_args =['-static']
                )

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(name="skyline_solver",
      version="0.0.1",
      author="Mojtaba Farrokh",
      email="farrokh959@gmail.com",
      description="A Skyline solver for linear sets",
      long_description=long_description,
      long_description_content_type="text/markdown",
      packages=["skyline_solver","skyline_solver/skyline"], #find_packages(where="src"),
      ext_modules=[ext1],
      install_requires = ["numpy"],
      python_requires='>=3')



from skyline import skyline
import numpy as np

class skyline_solver:
    def __init__(self,m):
        skyline.init(np.array(m,dtype=int,order='F'))
        self.rank=skyline.dof_total
        self.nnz=skyline.nnz
    
    def add_value(self,i,j,v):
        skyline.add_value(i,j,v)
    
    def decompose(self):
        skyline.decompose()
    
    def solve(self,f):
        x = np.array(f,dtype=float,order='F')
        skyline.solve(x)
        return x

    
    def to_dense(self):
        dof = skyline.dof_total
        d = np.zeros((dof,dof),dtype=float,order='F')
        skyline.to_dense(d)
        return d
    
    def get_skylineVector(self):
        return skyline.m
    
    def get_valuesVector(self):
        return skyline.a
    
    def get_rank(self):
        return skyline.dof_total
    
    def get_value(self,i,j):
        v = skyline.get_value(i,j)
        return v
    
    def set_value(self,i,j,v):
        skyline.set_value(i,j,v)
    
    def set(self,v):
        skyline.set(v)
    
